@@ -19,6 +19,7 @@ logging=logger.get_logger(name='gc_helper')
 
 GOOGLE_PROJECT_ID = os.getenv("GOOGLE_PROJECT_ID")
 SERVICE_NAME = os.getenv("SERVICE_NAME")
+ENV = os.getenv("ENV")
 
 
 def create_service_account(service_account):
@@ -91,7 +92,7 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = ["GOOGLE_PROJECT_ID", "SERVICE_NAME"]
+    envs = ["GOOGLE_PROJECT_ID", "SERVICE_NAME", "ENV"]
     envs = [f"{env}={eval(env)}" for env in envs]
     env_list_string=','.join(envs)
     
