@@ -13,8 +13,7 @@ model_module = import_module(mlops_settings["model_import_path"])
 train = model_module.train
 ModelException = model_module.ModelException
 
-import akerbp.mlops.cdf.helpers as helpers
-from akerbp.mlops.model_manager import upload_new_model_version
+import akerbp.mlops.model_manager as mm
 from akerbp.mlops import __version__ as version
 from akerbp.mlops.core import logger 
 
@@ -25,14 +24,13 @@ logging.debug(f"MLOps framework version {version}")
 ENV = os.getenv('ENV')
 
 
-def _saver(api_keys, path, metadata):
+def _saver(path, metadata, cdf_api_keys):
     """
     Upload model folder to CDF Files
     """
     model_name = mlops_settings['model_name']
-    helpers.api_keys=api_keys
-    helpers.set_up_cdf_client()
-    model_info = upload_new_model_version(
+    mm.setup(cdf_api_keys)
+    model_info = mm.upload_new_model_version(
         model_name, 
         ENV,  
         path,
@@ -59,7 +57,7 @@ def service(data, secrets, saver=_saver):
         with TemporaryDirectory() as temp_dir:
             metadata = train(data=data, folder_path=temp_dir, secrets=secrets)
             logging.debug(f"{metadata=}")
-            model_info = saver(secrets, temp_dir, metadata)
+            model_info = saver(temp_dir, metadata, secrets)
         return dict(status="ok", training=model_info)
     except ModelException as e:
         error_message = f"Training failed. Message: {e}"
